==> kiwix-desktop-debug-2.3.1-3-x86_64.pkg.tar.zst: usr/src/debug/kiwix-desktop/kiwix-desktop-2.3.1/qrc_settingsmanager.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 5.15.9
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

static const unsigned char qt_resource_data[] = {
  // /build/kiwix-desktop/src/kiwix-desktop-2.3.1/resources/css/_settingsManager.css
  0x0,0x0,0x3,0x6e,
  0x51,
  0x57,0x69,0x64,0x67,0x65,0x74,0x23,0x77,0x69,0x64,0x67,0x65,0x74,0x20,0x7b,0xa,
  0x20,0x20,0x20,0x20,0x6d,0x61,0x78,0x2d,0x77,0x69,0x64,0x74,0x68,0x3a,0x20,0x36,
  0x30,0x30,0x3b,0xa,0x7d,0xa,0xa,0x51,0x4c,0x61,0x62,0x65,0x6c,0x2c,0xa,0x51,
  0x50,0x75,0x73,0x68,0x42,0x75,0x74,0x74,0x6f,0x6e,0x2c,0xa,0x51,0x53,0x70,0x69,
  0x6e,0x42,0x6f,0x78,0x20,0x7b,0xa,0x20,0x20,0x20,0x20,0x66,0x6f,0x6e,0x74,0x2d,
  0x73,0x69,0x7a,0x65,0x3a,0x20,0x31,0x36,0x70,0x78,0x3b,0xa,0x20,0x20,0x20,0x20,
  0x6c,0x69,0x6e,0x65,0x2d,0x68,0x65,0x69,0x67,0x68,0x74,0x3a,0x20,0x32,0x34,0x70,
  0x78,0x3b,0xa,0x7d,0xa,0xa,0x51,0x4c,0x61,0x62,0x65,0x6c,0x2c,0xa,0x51,0x50,
  0x75,0x73,0x68,0x42,0x75,0x74,0x74,0x6f,0x6e,0x20,0x7b,0xa,0x20,0x20,0x20,0x20,
  0x70,0x61,0x64,0x64,0x69,0x6e,0x67,0x3a,0x20,0x31,0x32,0x70,0x78,0x20,0x38,0x70,
  0x78,0x3b,0xa,0x7d,0xa,0xa,0x51,0x46,0x72,0x61,0x6d,0x65,0x5b,0x66,0x72,0x61,
  0x6d,0x65,0x53,0x68,0x61,0x70,0x65,0x3d,0x22,0x34,0x22,0x5d,0x20,0x7b,0xa,0x20,
  0x20,0x20,0x20,0x2f,0x2a,0x66,0x72,0x61,0x6d,0x65,0x53,0x68,0x61,0x70,0x65,0x20,
  0x34,0x20,0x69,0x73,0x20,0x48,0x4c,0x69,0x6e,0x65,0x20,0x2a,0x2f,0xa,0x20,0x20,
  0x20,0x20,0x62,0x6f,0x72,0x64,0x65,0x72,0x3a,0x20,0x31,0x70,0x78,0x20,0x73,0x6f,
  0x6c,0x69,0x64,0x20,0x23,0x65,0x61,0x65,0x63,0x66,0x30,0x3b,0xa,0x20,0x20,0x20,
  0x20,0x6d,0x69,0x6e,0x2d,0x68,0x65,0x69,0x67,0x68,0x74,0x3a,0x20,0x30,0x3b,0xa,
  0x20,0x20,0x20,0x20,0x6d,0x61,0x78,0x2d,0x68,0x65,0x69,0x67,0x68,0x74,0x3a,0x20,
  0x31,0x70,0x74,0x3b,0xa,0x7d,0xa,0xa,0x51,0x4c,0x61,0x62,0x65,0x6c,0x23,0x73,
  0x65,0x74,0x74,0x69,0x6e,0x67,0x73,0x4c,0x61,0x62,0x65,0x6c,0x20,0x7b,0xa,0x20,
  0x20,0x20,0x20,0x66,0x6f,0x6e,0x74,0x2d,0x73,0x69,0x7a,0x65,0x3a,0x20,0x33,0x32,
  0x70,0x78,0x3b,0xa,0x20,0x20,0x20,0x20,0x6c,0x69,0x6e,0x65,0x2d,0x68,0x65,0x69,
  0x67,0x68,0x74,0x3a,0x20,0x34,0x34,0x70,0x78,0x3b,0xa,0x20,0x20,0x20,0x20,0x66,
  0x6f,0x6e,0x74,0x2d,0x77,0x65,0x69,0x67,0x68,0x74,0x3a,0x20,0x62,0x6f,0x6c,0x64,
  0x3b,0xa,0x7d,0xa,0x51,0x53,0x70,0x69,0x6e,0x42,0x6f,0x78,0x2c,0xa,0x51,0x4c,
  0x61,0x62,0x65,0x6c,0x23,0x64,0x6f,0x77,0x6e,0x6c,0x6f,0x61,0x64,0x44,0x69,0x72,
  0x50,0x61,0x74,0x68,0x2c,0x20,0x23,0x6d,0x6f,0x6e,0x69,0x74,0x6f,0x72,0x44,0x69,
  0x72,0x50,0x61,0x74,0x68,0x20,0x7b,0xa,0x20,0x20,0x20,0x20,0x66,0x6f,0x6e,0x74,
  0x3a,0x20,0x62,0x6f,0x6c,0x64,0x20,0x31,0x32,0x70,0x74,0x3b,0xa,0x7d,0xa,0x51,
  0x50,0x75,0x73,0x68,0x42,0x75,0x74,0x74,0x6f,0x6e,0x20,0x7b,0xa,0x20,0x20,0x20,
  0x20,0x62,0x61,0x63,0x6b,0x67,0x72,0x6f,0x75,0x6e,0x64,0x2d,0x63,0x6f,0x6c,0x6f,
  0x72,0x3a,0x20,0x77,0x68,0x69,0x74,0x65,0x3b,0xa,0x20,0x20,0x20,0x20,0x63,0x6f,
  0x6c,0x6f,0x72,0x3a,0x20,0x23,0x33,0x33,0x36,0x36,0x63,0x63,0x3b,0xa,0x20,0x20,
  0x20,0x20,0x70,0x61,0x64,0x64,0x69,0x6e,0x67,0x3a,0x20,0x34,0x70,0x78,0x3b,0xa,
  0x20,0x20,0x20,0x20,0x66,0x6f,0x6e,0x74,0x3a,0x20,0x62,0x6f,0x6c,0x64,0x3b,0xa,
  0x20,0x20,0x20,0x20,0x62,0x6f,0x72,0x64,0x65,0x72,0x2d,0x72,0x61,0x64,0x69,0x75,
  0x73,0x3a,0x20,0x34,0x70,0x78,0x3b,0xa,0x7d,0xa,0xa,0x51,0x50,0x75,0x73,0x68,
  0x42,0x75,0x74,0x74,0x6f,0x6e,0x3a,0x68,0x6f,0x76,0x65,0x72,0x20,0x7b,0xa,0x20,
  0x20,0x20,0x20,0x62,0x61,0x63,0x6b,0x67,0x72,0x6f,0x75,0x6e,0x64,0x2d,0x63,0x6f,
  0x6c,0x6f,0x72,0x3a,0x20,0x23,0x33,0x33,0x36,0x36,0x63,0x63,0x3b,0xa,0x20,0x20,
  0x20,0x20,0x63,0x6f,0x6c,0x6f,0x72,0x3a,0x20,0x77,0x68,0x69,0x74,0x65,0x3b,0xa,
  0x7d,0xa,0xa,0x23,0x6d,0x6f,0x6e,0x69,0x74,0x6f,0x72,0x44,0x69,0x72,0x4c,0x61,
  0x62,0x65,0x6c,0x20,0x7b,0xa,0x20,0x20,0x20,0x20,0x70,0x61,0x64,0x64,0x69,0x6e,
  0x67,0x2d,0x72,0x69,0x67,0x68,0x74,0x3a,0x20,0x30,0x3b,0xa,0x7d,0xa,0xa,0x23,
  0x6d,0x6f,0x6e,0x69,0x74,0x6f,0x72,0x48,0x65,0x6c,0x70,0x20,0x7b,0xa,0x20,0x20,
  0x20,0x20,0x70,0x61,0x64,0x64,0x69,0x6e,0x67,0x3a,0x20,0x31,0x3b,0xa,0x20,0x20,
  0x20,0x20,0x6d,0x61,0x72,0x67,0x69,0x6e,0x3a,0x20,0x30,0x3b,0xa,0x20,0x20,0x20,
  0x20,0x62,0x61,0x63,0x6b,0x67,0x72,0x6f,0x75,0x6e,0x64,0x3a,0x20,0x23,0x36,0x36,
  0x36,0x36,0x36,0x36,0x3b,0xa,0x20,0x20,0x20,0x20,0x63,0x6f,0x6c,0x6f,0x72,0x3a,
  0x20,0x77,0x68,0x69,0x74,0x65,0x3b,0xa,0x20,0x20,0x20,0x20,0x62,0x6f,0x72,0x64,
  0x65,0x72,0x2d,0x72,0x61,0x64,0x69,0x75,0x73,0x3a,0x20,0x32,0x70,0x78,0x3b,0xa,
  0x20,0x20,0x20,0x20,0x6d,0x61,0x78,0x2d,0x68,0x65,0x69,0x67,0x68,0x74,0x3a,0x20,
  0x31,0x38,0x70,0x78,0x3b,0xa,0x20,0x20,0x20,0x20,0x6d,0x69,0x6e,0x2d,0x77,0x69,
  0x64,0x74,0x68,0x3a,0x20,0x31,0x34,0x70,0x78,0x3b,0xa,0x20,0x20,0x20,0x20,0x66,
  0x6f,0x6e,0x74,0x3a,0x20,0x62,0x6f,0x6c,0x64,0x3b,0xa,0x7d,0xa,
  
};

static const unsigned char qt_resource_name[] = {
  // css
  0x0,0x3,
  0x0,0x0,0x6a,0xa3,
  0x0,0x63,
  0x0,0x73,0x0,0x73,
    // _settingsManager.css
  0x0,0x14,
  0x1,0xed,0xd0,0x23,
  0x0,0x5f,
  0x0,0x73,0x0,0x65,0x0,0x74,0x0,0x74,0x0,0x69,0x0,0x6e,0x0,0x67,0x0,0x73,0x0,0x4d,0x0,0x61,0x0,0x6e,0x0,0x61,0x0,0x67,0x0,0x65,0x0,0x72,0x0,0x2e,
  0x0,0x63,0x0,0x73,0x0,0x73,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x1,0x88,0x40,0x20,0x7,0xc8,
  // :/css
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
0x0,0x0,0x1,0x88,0x40,0x20,0x7,0xc8,
  // :/css/_settingsManager.css
  0x0,0x0,0x0,0xc,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x88,0x40,0x20,0x7,0xc8,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#ifdef QT_NAMESPACE
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);
bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_settingsmanager)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_settingsmanager)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_settingsmanager)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_settingsmanager)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_settingsmanager)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_settingsmanager)(); }
   } dummy;
}

==> kiwix-desktop-debug-2.3.1-5-x86_64.pkg.tar.zst: usr/src/debug/kiwix-desktop/kiwix-desktop-2.3.1/qrc_settingsmanager.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 5.15.11
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

static const unsigned char qt_resource_data[] = {
  // /build/kiwix-desktop/src/kiwix-desktop-2.3.1/resources/css/_settingsManager.css
  0x0,0x0,0x3,0x6e,
  0x51,
  0x57,0x69,0x64,0x67,0x65,0x74,0x23,0x77,0x69,0x64,0x67,0x65,0x74,0x20,0x7b,0xa,
  0x20,0x20,0x20,0x20,0x6d,0x61,0x78,0x2d,0x77,0x69,0x64,0x74,0x68,0x3a,0x20,0x36,
  0x30,0x30,0x3b,0xa,0x7d,0xa,0xa,0x51,0x4c,0x61,0x62,0x65,0x6c,0x2c,0xa,0x51,
  0x50,0x75,0x73,0x68,0x42,0x75,0x74,0x74,0x6f,0x6e,0x2c,0xa,0x51,0x53,0x70,0x69,
  0x6e,0x42,0x6f,0x78,0x20,0x7b,0xa,0x20,0x20,0x20,0x20,0x66,0x6f,0x6e,0x74,0x2d,
  0x73,0x69,0x7a,0x65,0x3a,0x20,0x31,0x36,0x70,0x78,0x3b,0xa,0x20,0x20,0x20,0x20,
  0x6c,0x69,0x6e,0x65,0x2d,0x68,0x65,0x69,0x67,0x68,0x74,0x3a,0x20,0x32,0x34,0x70,
  0x78,0x3b,0xa,0x7d,0xa,0xa,0x51,0x4c,0x61,0x62,0x65,0x6c,0x2c,0xa,0x51,0x50,
  0x75,0x73,0x68,0x42,0x75,0x74,0x74,0x6f,0x6e,0x20,0x7b,0xa,0x20,0x20,0x20,0x20,
  0x70,0x61,0x64,0x64,0x69,0x6e,0x67,0x3a,0x20,0x31,0x32,0x70,0x78,0x20,0x38,0x70,
  0x78,0x3b,0xa,0x7d,0xa,0xa,0x51,0x46,0x72,0x61,0x6d,0x65,0x5b,0x66,0x72,0x61,
  0x6d,0x65,0x53,0x68,0x61,0x70,0x65,0x3d,0x22,0x34,0x22,0x5d,0x20,0x7b,0xa,0x20,
  0x20,0x20,0x20,0x2f,0x2a,0x66,0x72,0x61,0x6d,0x65,0x53,0x68,0x61,0x70,0x65,0x20,
  0x34,0x20,0x69,0x73,0x20,0x48,0x4c,0x69,0x6e,0x65,0x20,0x2a,0x2f,0xa,0x20,0x20,
  0x20,0x20,0x62,0x6f,0x72,0x64,0x65,0x72,0x3a,0x20,0x31,0x70,0x78,0x20,0x73,0x6f,
  0x6c,0x69,0x64,0x20,0x23,0x65,0x61,0x65,0x63,0x66,0x30,0x3b,0xa,0x20,0x20,0x20,
  0x20,0x6d,0x69,0x6e,0x2d,0x68,0x65,0x69,0x67,0x68,0x74,0x3a,0x20,0x30,0x3b,0xa,
  0x20,0x20,0x20,0x20,0x6d,0x61,0x78,0x2d,0x68,0x65,0x69,0x67,0x68,0x74,0x3a,0x20,
  0x31,0x70,0x74,0x3b,0xa,0x7d,0xa,0xa,0x51,0x4c,0x61,0x62,0x65,0x6c,0x23,0x73,
  0x65,0x74,0x74,0x69,0x6e,0x67,0x73,0x4c,0x61,0x62,0x65,0x6c,0x20,0x7b,0xa,0x20,
  0x20,0x20,0x20,0x66,0x6f,0x6e,0x74,0x2d,0x73,0x69,0x7a,0x65,0x3a,0x20,0x33,0x32,
  0x70,0x78,0x3b,0xa,0x20,0x20,0x20,0x20,0x6c,0x69,0x6e,0x65,0x2d,0x68,0x65,0x69,
  0x67,0x68,0x74,0x3a,0x20,0x34,0x34,0x70,0x78,0x3b,0xa,0x20,0x20,0x20,0x20,0x66,
  0x6f,0x6e,0x74,0x2d,0x77,0x65,0x69,0x67,0x68,0x74,0x3a,0x20,0x62,0x6f,0x6c,0x64,
  0x3b,0xa,0x7d,0xa,0x51,0x53,0x70,0x69,0x6e,0x42,0x6f,0x78,0x2c,0xa,0x51,0x4c,
  0x61,0x62,0x65,0x6c,0x23,0x64,0x6f,0x77,0x6e,0x6c,0x6f,0x61,0x64,0x44,0x69,0x72,
  0x50,0x61,0x74,0x68,0x2c,0x20,0x23,0x6d,0x6f,0x6e,0x69,0x74,0x6f,0x72,0x44,0x69,
  0x72,0x50,0x61,0x74,0x68,0x20,0x7b,0xa,0x20,0x20,0x20,0x20,0x66,0x6f,0x6e,0x74,
  0x3a,0x20,0x62,0x6f,0x6c,0x64,0x20,0x31,0x32,0x70,0x74,0x3b,0xa,0x7d,0xa,0x51,
  0x50,0x75,0x73,0x68,0x42,0x75,0x74,0x74,0x6f,0x6e,0x20,0x7b,0xa,0x20,0x20,0x20,
  0x20,0x62,0x61,0x63,0x6b,0x67,0x72,0x6f,0x75,0x6e,0x64,0x2d,0x63,0x6f,0x6c,0x6f,
  0x72,0x3a,0x20,0x77,0x68,0x69,0x74,0x65,0x3b,0xa,0x20,0x20,0x20,0x20,0x63,0x6f,
  0x6c,0x6f,0x72,0x3a,0x20,0x23,0x33,0x33,0x36,0x36,0x63,0x63,0x3b,0xa,0x20,0x20,
  0x20,0x20,0x70,0x61,0x64,0x64,0x69,0x6e,0x67,0x3a,0x20,0x34,0x70,0x78,0x3b,0xa,
  0x20,0x20,0x20,0x20,0x66,0x6f,0x6e,0x74,0x3a,0x20,0x62,0x6f,0x6c,0x64,0x3b,0xa,
  0x20,0x20,0x20,0x20,0x62,0x6f,0x72,0x64,0x65,0x72,0x2d,0x72,0x61,0x64,0x69,0x75,
  0x73,0x3a,0x20,0x34,0x70,0x78,0x3b,0xa,0x7d,0xa,0xa,0x51,0x50,0x75,0x73,0x68,
  0x42,0x75,0x74,0x74,0x6f,0x6e,0x3a,0x68,0x6f,0x76,0x65,0x72,0x20,0x7b,0xa,0x20,
  0x20,0x20,0x20,0x62,0x61,0x63,0x6b,0x67,0x72,0x6f,0x75,0x6e,0x64,0x2d,0x63,0x6f,
  0x6c,0x6f,0x72,0x3a,0x20,0x23,0x33,0x33,0x36,0x36,0x63,0x63,0x3b,0xa,0x20,0x20,
  0x20,0x20,0x63,0x6f,0x6c,0x6f,0x72,0x3a,0x20,0x77,0x68,0x69,0x74,0x65,0x3b,0xa,
  0x7d,0xa,0xa,0x23,0x6d,0x6f,0x6e,0x69,0x74,0x6f,0x72,0x44,0x69,0x72,0x4c,0x61,
  0x62,0x65,0x6c,0x20,0x7b,0xa,0x20,0x20,0x20,0x20,0x70,0x61,0x64,0x64,0x69,0x6e,
  0x67,0x2d,0x72,0x69,0x67,0x68,0x74,0x3a,0x20,0x30,0x3b,0xa,0x7d,0xa,0xa,0x23,
  0x6d,0x6f,0x6e,0x69,0x74,0x6f,0x72,0x48,0x65,0x6c,0x70,0x20,0x7b,0xa,0x20,0x20,
  0x20,0x20,0x70,0x61,0x64,0x64,0x69,0x6e,0x67,0x3a,0x20,0x31,0x3b,0xa,0x20,0x20,
  0x20,0x20,0x6d,0x61,0x72,0x67,0x69,0x6e,0x3a,0x20,0x30,0x3b,0xa,0x20,0x20,0x20,
  0x20,0x62,0x61,0x63,0x6b,0x67,0x72,0x6f,0x75,0x6e,0x64,0x3a,0x20,0x23,0x36,0x36,
  0x36,0x36,0x36,0x36,0x3b,0xa,0x20,0x20,0x20,0x20,0x63,0x6f,0x6c,0x6f,0x72,0x3a,
  0x20,0x77,0x68,0x69,0x74,0x65,0x3b,0xa,0x20,0x20,0x20,0x20,0x62,0x6f,0x72,0x64,
  0x65,0x72,0x2d,0x72,0x61,0x64,0x69,0x75,0x73,0x3a,0x20,0x32,0x70,0x78,0x3b,0xa,
  0x20,0x20,0x20,0x20,0x6d,0x61,0x78,0x2d,0x68,0x65,0x69,0x67,0x68,0x74,0x3a,0x20,
  0x31,0x38,0x70,0x78,0x3b,0xa,0x20,0x20,0x20,0x20,0x6d,0x69,0x6e,0x2d,0x77,0x69,
  0x64,0x74,0x68,0x3a,0x20,0x31,0x34,0x70,0x78,0x3b,0xa,0x20,0x20,0x20,0x20,0x66,
  0x6f,0x6e,0x74,0x3a,0x20,0x62,0x6f,0x6c,0x64,0x3b,0xa,0x7d,0xa,
  
};

static const unsigned char qt_resource_name[] = {
  // css
  0x0,0x3,
  0x0,0x0,0x6a,0xa3,
  0x0,0x63,
  0x0,0x73,0x0,0x73,
    // _settingsManager.css
  0x0,0x14,
  0x1,0xed,0xd0,0x23,
  0x0,0x5f,
  0x0,0x73,0x0,0x65,0x0,0x74,0x0,0x74,0x0,0x69,0x0,0x6e,0x0,0x67,0x0,0x73,0x0,0x4d,0x0,0x61,0x0,0x6e,0x0,0x61,0x0,0x67,0x0,0x65,0x0,0x72,0x0,0x2e,
  0x0,0x63,0x0,0x73,0x0,0x73,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x1,0x8b,0xce,0xdd,0xfa,0x80,
  // :/css
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
0x0,0x0,0x1,0x8b,0xce,0xdd,0xfa,0x80,
  // :/css/_settingsManager.css
  0x0,0x0,0x0,0xc,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x8b,0xce,0xdd,0xfa,0x80,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#ifdef QT_NAMESPACE
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);
bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_settingsmanager)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_settingsmanager)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_settingsmanager)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_settingsmanager)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_settingsmanager)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_settingsmanager)(); }
   } dummy;
}
